@@ -1,5 +1,6 @@
 from datetime import datetime
 from enum import Enum
+import os
 import sys
 import argparse
 import netrc
@@ -59,9 +60,10 @@ def main():  # noqa: C901
                         help='Password for MQTT broker', required=False)
     parser.add_argument('-u', '--username', type=str, help='Username of Volkswagen id', required=False)
     parser.add_argument('-p', '--password', type=str, help='Password of Volkswagen id', required=False)
-    parser.add_argument('--netrc', type=str, help='File in netrc syntax providing login, default is the default netrc '
-                        'location (usually your users folder). Netrc is only used when username and password are not '
-                        'provided as arguments', default=None, required=False)
+    defaultNetRc = os.path.join(os.path.expanduser("~"), ".netrc")
+    parser.add_argument('--netrc', help=f'File in netrc syntax providing login (default: {defaultNetRc}).'
+                        ' Netrc is only used when username and password are not provided  as arguments',
+                        default=None, required=False)
     parser.add_argument('-i', '--interval', help='Query interval in seconds',
                               type=NumberRangeArgument(300, 3500), required=False, default=300)
     parser.add_argument('--prefix', help='MQTT topic prefix',
@@ -77,12 +79,25 @@ def main():  # noqa: C901
         username = args.username
         password = args.password
     else:
+        if args.netrc is not None:
+            netRcFilename = args.netrc
+        else:
+            netRcFilename = defaultNetRc
         try:
             secrets = netrc.netrc(file=args.netrc)
-            username, _, password = secrets.authenticators("volkswagen.de")
+            secret = secrets.authenticators("volkswagen.de")
+            username, _, password = secret
+        except TypeError:
+            if not args.username:
+                LOG.error('volkswagen.de entry was not found in %s netrc-file. Create it or provide at least a username'
+                          ' with --username', netRcFilename)
+                sys.exit(1)
+            username = args.username
+            password = getpass.getpass()
         except FileNotFoundError:
             if not args.username:
-                LOG.error('.netrc file was not found. Create it or provide at least a username with --username')
+                LOG.error('%s netrc-file was not found. Create it or provide at least a username with --username',
+                          netRcFilename)
                 sys.exit(1)
             username = args.username
             password = getpass.getpass()
@@ -95,6 +110,10 @@ def main():  # noqa: C901
         mqttpassword = args.mqttpassword
 
     if mqttusername is None and mqttpassword is None:
+        if args.netrc is not None:
+            netRcFilename = args.netrc
+        else:
+            netRcFilename = defaultNetRc
         try:
             secrets = netrc.netrc(file=args.netrc)
             authenticator = secrets.authenticators(args.mqttbroker)
@@ -102,7 +121,8 @@ def main():  # noqa: C901
                 mqttusername, _, mqttpassword = authenticator
         except FileNotFoundError:
             if args.netrc is not None:
-                LOG.error('Provided .netrc file was not found.')
+                LOG.error('%s netrc-file was not found. Create it or provide at least a username with --username',
+                          netRcFilename)
                 sys.exit(1)
 
     logging.basicConfig(level=logging.INFO)
@@ -112,12 +132,20 @@ def main():  # noqa: C901
     if mqttusername is not None:
         mqttCLient.username_pw_set(username=mqttusername, password=mqttpassword)
 
-    mqttCLient.connectWeConnect(username=username, password=password)
-    mqttCLient.connect(args.mqttbroker, args.mqttport, 60)
-    # blocking run
-    mqttCLient.run()
-    mqttCLient.disconnect()
-    mqttCLient.weConnect.persistTokens()
+    try:
+        mqttCLient.connectWeConnect(username=username, password=password)
+        mqttCLient.connect(args.mqttbroker, args.mqttport, 60)
+        # blocking run
+        mqttCLient.run()
+        mqttCLient.disconnect()
+        mqttCLient.weConnect.persistTokens()
+    except weconnect.AuthentificationError as e:
+        LOG.critical('There was a problem when authenticating with WeConnect: %s', e)
+    except weconnect.APICompatibilityError as e:
+        LOG.critical('There was a problem when communicating with WeConnect.'
+                     ' If this problem persists please open a bug report: %s', e)
+    finally:
+        mqttCLient.disconnect()
 
 
 class WeConnectMQTTClient(paho.mqtt.client.Client):
